# Joule in SAP LeanIX
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/joule-in-sap-leanix#introduction)
  * [Capabilities](https://help.sap.com/docs/leanix/ea/joule-in-sap-leanix#capabilities)
  * [Accessing Joule](https://help.sap.com/docs/leanix/ea/joule-in-sap-leanix#accessing-joule)


Joule is an AI assistant in SAP that helps you access resources and find information through conversational interactions. Learn how to access it and leverage its features.
